
.. py:currentmodule:: pythreejs

LineBasicMaterial
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: LineBasicMaterial()
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Material`.

    Three.js docs: https://threejs.org/docs/#api/materials/LineBasicMaterial


    .. py:attribute:: color

        .. sourcecode:: python

            Unicode("#ffffff", allow_none=False).tag(sync=True)

    .. py:attribute:: lights

        .. sourcecode:: python

            Bool(False, allow_none=False).tag(sync=True)

    .. py:attribute:: linewidth

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

    .. py:attribute:: linecap

        .. sourcecode:: python

            Unicode("round", allow_none=False).tag(sync=True)

    .. py:attribute:: linejoin

        .. sourcecode:: python

            Unicode("round", allow_none=False).tag(sync=True)

